<?php

namespace App\Http\Controllers;

use App\Models\Permiso;
use Illuminate\Http\Request;

class PermisoController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
        $this->authorize("viewAny_permiso");
        $permisos = Permiso::paginate(25);
        return response()->json($permisos, 200);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
        $this->authorize("create_permiso");
        $request->validate([
            "detalle" => "required|max:30|unique:permisos",
            "action" => "required|max:30",
            "subject" => "required|max:30"
        ]);
        //guardamos
        $permiso = new Permiso;
        $permiso->detalle = $request->detalle;
        $permiso->action = $request->action;
        $permiso->subject = $request->subject;
        $permiso->save();

        return response()->json([
            "status" => true,
            "message" => "Permiso registrado correctamente",
            "data" => $permiso
        ], 201);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
        $this->authorize("view_permiso");
        $permiso = Permiso::findOrFail($id);
        return response()->json($permiso, 200);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
        $this->authorize("update_permiso");
        $request->validate([
            "detalle" => "required|max:30|unique:permisos,detalle,$id",
            "action" => "required|max:30",
            "subject" => "required|max:30"
        ]);

        $permiso = Permiso::find($id);
        $permiso->detalle = $request->detalle;
        $permiso->action = $request->action;
        $permiso->subject = $request->subject;
        $permiso->update();

        return response()->json([
            "status" => true,
            "message" => "Permiso actualizado correctamente",
            "data" => $permiso
        ], 200);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
        $this->authorize("delete_permiso");
        $permiso = Permiso::find($id);
        $permiso->delete();

        return response()->json([
            "status" => true,
            "message" => "Permiso eliminado correctamente"
        ], 200);
    }
}
