<?php

namespace App\Http\Controllers;

use App\Models\Role;
use Illuminate\Http\Request;

class RoleController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //

        $this->authorize("viewAny_role");

        //$roles = Role::get();
        $roles = Role::with('permisos')->get();

        return response()->json([
            "success" => true,
            "roles" => $roles
        ], 200);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //
        $this->authorize("create_role");
        // validacion
        $request->validate([
            "nombre" => "required|unique:roles"
        ]);
        // guardamos
        $rol = new Role;
        $rol->nombre = $request->nombre;
        $rol->detalle = $request->detalle;
        $rol->save();
        // respuesta
        return response()->json([
            'success' => true,
            "mensaje" => "Rol registrado correctamente"
        ], 201);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
        $this->authorize("view_role");
        $rol = Role::with('permisos')->find($id);
        // $rol = Role::with('permisos')->find($id);
        return response()->json([
            'success' => true,
            'rol' => $rol,
        ], 200);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
        $this->authorize("update_role");
        // validacion
        $request->validate([
            "nombre" => "required|unique:roles,nombre,$id"
        ]);

        $rol = Role::find($id);
        $rol->nombre = $request->nombre;
        $rol->detalle = $request->detalle;
        $rol->update();
        // respuesta
        return response()->json([
            'success' => true,
            "mensaje" => "Rol actualizado correctamente"
        ], 200);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {

        $this->authorize("delete_role");
        $rol = Role::find($id);
        $rol->delete();
        // respuesta
        return response()->json([
            'success' => true,
            "mensaje" => "Rol eliminado correctamente"
        ], 200);
    }
    public function asignarPermiso(Request $request)
    {
        $rol = Role::find($request->role_id);
        // $rol->assignRole($request->role);
        $rol->permisos()->sync($request->permisos);

        return response()->json([
            "status" => true,
            "mensaje" => "Permisos Asignados correctamente",
            //  "rol" => $rol,
            // "permisos" => $request->permisos,
        ], 200);
    }
}
