<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;

class UsuarioController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        //
        $this->authorize("viewAny_user");

        $usuarios = User::where('registrado', 0)
            ->where('cuenta', 0)->with('roles')->paginate(10);
        // $usuarios = User::paginate(10);
        //$usuarios = User::get();
        return response()->json([
            "status" => true,
            "usuario" => $usuarios
        ], 200);
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        //


        $this->authorize("create_user");

        // validar
        $request->validate([
            "name" => "required",
            "email" => "required|email|unique:users",
            "password" => "required|string|min:6"
        ]);
        // guardar como objeto
        $usuario = new User();
        $usuario->name = $request->name;
        $usuario->email = $request->email;
        $usuario->password = bcrypt($request->password);
        $usuario->save();
        // responder
        return response()->json([
            "status" => true,
            "mensaje" => "Usuario registrado correctamente"
        ], 201);
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
        $this->authorize("show_user");

        $usuario = User::find($id);
        return response()->json([
            "status" => true,
            "usuario" => $usuario
        ], 200);
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        //
        $this->authorize("update_user");
        // validar
        $request->validate([

            "name" => "required",
            "email" => "required|unique:users,email,$id"
        ]);
        // modificar
        $usuario = User::find($id);
        $usuario->name = $request->name;
        $usuario->email = $request->email;
        if ($request->password) {
            $usuario->password = bcrypt($request->password);
        }
        $usuario->update();
        // responder
        return response()->json([
            "status" => true,
            "mensaje" => "Usuario modificado correctamente"
        ], 200);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
        $this->authorize("delete_user");

        $usuario = User::find($id);
        $usuario->delete();

        return response()->json([
            "status" => true,
            "mensaje" => "Usuario eliminado correctamente"
        ], 200);
    }
    public function asignarRol(Request $request)
    {
        $user = User::find($request->user_id);
        $user->assignRole($request->role);

        return response()->json([
            "status" => true,
            "mensaje" => "Rol Asignado correctamente"
        ], 200);
    }

    public function quitarRol(Request $request)
    {
        $user = User::find($request->user_id);
        $user->removeRole($request->role);

        return response()->json([
            "status" => true,
            "mensaje" => "Rol Desvinculado"
        ], 200);
    }
}
