<?php

use App\Http\Controllers\AuthController;
use App\Http\Controllers\BnbController;
use App\Http\Controllers\CarbonController;
use App\Http\Controllers\MensajeController;
use App\Http\Controllers\PermisoController;
use App\Http\Controllers\PlanController;
use App\Http\Controllers\RoleController;
use App\Http\Controllers\SintesiController;
use App\Http\Controllers\SmartController;
use App\Http\Controllers\UsuarioController;
use App\Http\Controllers\WisproController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
    return $request->user();
});

Route::post('bnbapi/create/notification', [BnbController::class, 'crear_notificacion'])->middleware('checkHeader');

Route::post('sintesis/crear_notificacion_sintesis', [SintesiController::class, 'crear_notificacion_sintesis']);
// Route::post('bnbapi/create/notification', [BnbController::class, 'crear_notificacion'])->middleware('api_token');
// Route::post('bnbapi/create/notification/{api}', [BnbController::class, 'crear_notificacion']);

//Autenticacion
Route::group(['prefix' => 'v1/auth'], function () {
    // para ingresar no necesita estar logueado
    // ruta /v1/auth/login
    Route::post('login', [AuthController::class, 'login']);
    Route::post('cliente', [AuthController::class, 'existe_cliente']);
    Route::post('registro', [AuthController::class, 'registrarse']);

    // para logout y perfil necesita estar logueado
    // protegemos con middelware

    Route::group(['middleware' => 'auth:sanctum'], function () {
        // ruta /v1/auth/logout
        Route::post('logout', [AuthController::class, 'logout']);
        // ruta /v1/auth/perfil
        Route::get('perfil', [AuthController::class, 'miPerfil']);
        Route::get('perfil_full', [AuthController::class, 'miPerfilFull']);
        Route::get('refresh', [AuthController::class, 'refresh']);
    });
});
// roles
Route::group(["prefix" => "v1", "middleware" => "auth:sanctum"], function () {

    Route::post("usuario/asignar-rol", [UsuarioController::class, "asignarRol"]);
    Route::post("usuario/quitar-rol", [UsuarioController::class, "quitarRol"]);

    // rol
    Route::post("role/asignar-permiso", [RoleController::class, "asignarPermiso"]);

    Route::apiResource("permiso", PermisoController::class);
    Route::apiResource("role", RoleController::class);
    Route::apiResource("usuario", UsuarioController::class);
    Route::apiResource("mensaje", MensajeController::class);
    Route::apiResource("plan", PlanController::class);

    //Wispro
    Route::get('wispro', [WisproController::class, 'lista_clientes']);
    Route::get('wispro/pagos', [WisproController::class, 'lista_pagos_clientes']);
    Route::get('wispro/deshabilitados', [WisproController::class, 'lista_contratos_deshabilitados']);

    Route::get('wispro/cliente2/{id}', [WisproController::class, 'actualizar_cliente']);
    Route::get('wispro/facturas', [WisproController::class, 'obtener_facturas']);
    Route::get('wispro/facturas/pagofactura/{id}', [WisproController::class, 'pagar_facturas']);
    // Route::get('wispro/pendientes', [WisproController::class, 'lista_pendientes']);
    Route::get('wispro/verfacturas/{id}', [WisproController::class, 'ver_facturas']);
    Route::get('wispro/misfacturaspagadas/{id}', [WisproController::class, 'mis_facturas_pagadas']);
    Route::get('wispro/update', [WisproController::class, 'actualiza_estado_cliente_smart']);

    //SMARTOLT
    Route::get('smart/enabled/{id}', [SmartController::class, 'habilitar_cattv']);
    Route::get('smart/disabled/{id}', [SmartController::class, 'deshabilitar_cattv']);
    Route::get('smart/status/{id}', [SmartController::class, 'status_cattv']);
    Route::get('smart/detalles/{id}', [SmartController::class, 'detalles_info_smart_cliente']);
    Route::get('smart/veriestado/{id}', [SmartController::class, 'verfica_estado_online']);
    Route::get('smart/ubicacion/{id}', [SmartController::class, 'obtener_lat_long']);
    Route::get('smart/senal/{id}', [SmartController::class, 'obtener_senal']);
    Route::get('smart/resumen/{id}', [SmartController::class, 'resumen_info_smart']);
    //PLAN
    Route::get('plan/lista', [PlanController::class, 'obtener_plan_lista']);

    //BNB
    Route::get('bnbapi', [BnbController::class, 'obtener_token']);
    Route::get('bnbapi/imageqr', [BnbController::class, 'obtener_imageQr']);
    Route::get('bnbapi/imageqr/date', [BnbController::class, 'obtener_imageQrGeneradosporFecha']);
    Route::get('bnbapi/imageqr/state/{id}', [BnbController::class, 'obtener_estado_imageQr']);
    Route::get('bnbapi/imageqr/cancel/{id}', [BnbController::class, 'cancelar_estado_imageQr']);
    Route::post('bnbapi/create/notification', [BnbController::class, 'crear_notificacion']);
    Route::post('wispro/client/update/{id}', [WisproController::class, 'actualizar_cliente']);
    Route::post('wispro/facturas/generarqr/{id}', [WisproController::class, 'generarQrPago']);
    Route::post('wispro/facturas/generarqr_por_custom/{id}', [WisproController::class, 'generarQrPagoPorCustomID']);
    Route::post('wispro/facturas/generar_qr_pago_adelantado/{id}', [WisproController::class, 'generarQrPagoAdelantado']);
    Route::post('wispro/buscarCliente', [WisproController::class, 'bucarCliente']);

    Route::get('wispro/facturas/pendientes/{id}', [WisproController::class, 'facturas_pendientes_pago']);
    Route::get('wispro/facturas/pendientes/ci/{id}', [WisproController::class, 'obtenerFacturasXCarnet']);
    Route::get('wispro/facturas/pago/adelantadas/{id}', [WisproController::class, 'pago_facturas_adelantadas']);
    Route::post('wispro/facturas/pendientes_por_customID/{id}', [WisproController::class, 'facturas_pendientes_pago_por_customID']);
    Route::get('wispro/facturas/promesa_de_pago/{id}', [WisproController::class, 'promesasPago']);
    Route::get('wispro/contratoprueba/{id}', [WisproController::class, 'pruebaCron']);
    Route::get('wispro/contrato/{id}', [WisproController::class, 'resumen_contrato']);
    Route::post('wispro/adicionarLista', [WisproController::class, 'adicionar_lista']);
    Route::get('wispro/pago/{id}', [WisproController::class, 'realizarPagoDespuesDeBnb']);
    Route::get('carbon', [CarbonController::class, 'fecha']);
    Route::get('wispro/mi_dasboard', [WisproController::class, 'infoDashboard']);
    Route::post('wispro/eliminarQr/{id}', [WisproController::class, 'eliminarQr']);
    Route::get('sintesis/lista', [SintesiController::class, 'lista']);
    Route::get('sintesis/listapagos', [SintesiController::class, 'listapagos']);
    Route::get('sintesis/listaErrorSintesis', [SintesiController::class, 'listaErrorSintesis']);
    Route::get('sintesis/lista_clientes_pagados', [SintesiController::class, 'lista_clientes_pagados']);

    Route::post('sintesis/bajaitemsintesis/{id}', [SintesiController::class, 'baja_item_sintesis']);
    Route::get('sintesis/logs', [SintesiController::class, 'getLogs']);
    Route::get('wispro/valida/{id}', [WisproController::class, 'verificacion2']);
    Route::get('sintesis/obtenerplan_nuevo/{id}', [SintesiController::class, 'obtenerPlanNuevo']);
    Route::post('wispro/compararCi/{id}', [WisproController::class, 'compararCiWisproDB']);
    Route::post('wispro/sincronizar/{id}', [WisproController::class, 'sincronizarCiWisproDB']);
   
    
    Route::get('sintesis/listaDeshabilitados', [SintesiController::class, 'lista_deshabilitados']);
    Route::post('sintesis/activar', [SintesiController::class, 'activarWispro']);
    
    
Route::get('sintesis/cronActivarDesactivar', [SintesiController::class, 'activar_desactivar']);
Route::get('sintesis/activarsmart178', [SintesiController::class, 'activar_smart_178']);

Route::get('sintesis/probando', [SintesiController::class, 'probando']);
Route::get('sintesis/probando_cron', [SintesiController::class, 'probandoCron']);
Route::get('sintesis/habilit', [SintesiController::class, 'habilitarEquipos']);
Route::get('sintesis/deshabilit', [SintesiController::class, 'deshabilitarEquipos']);



//para cargar
    Route::get('sintesis/cargardatos/{id}', [SintesiController::class, 'cargar_datos']);
 Route::get('sintesis/deletedatos', [SintesiController::class, 'delete_datos']);
});

// Route::get('wispro/prueba/{1}', [WisproController::class, 'verificacion']);

/*
"id": "6d2faf45-5770-46ab-9dae-a44530131390",
"public_id": 1499,
"custom_id": "200042",
"name": "Porfirio Pruebass 200",
---------------------
"id": "3aa54cb8-ce91-44c2-8d0e-c857ef2fecd5",
"public_id": 1500,
"custom_id": "200044",
"name": "Porfirio Pruebass 300",
-----------------------------------------
"id": "e7a3bfb4-c36b-4a14-b060-0918c98f2512",
"public_id": 1505,
"custom_id": "200047",
"name": "Porfirio Pruebas 400",
----------------    ------
"id": "9d41b652-b7dd-4a8e-a917-a5b65285fd85",
"public_id": 1506,
"custom_id": "200041",
"name": "Porfirio Pruebas 101",
 */
